Raft coordination module
This module is designed to be used as the coordination component in the dcs framework.
It implements the raft algorithm.
It’s main export is the RaftSDK including the RaftService.
This module is designed to be used as the coordination component in the dcs framework.
It implements the raft algorithm.
It’s main export is the RaftSDK including the RaftService.